<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
		xmlns:xlink="http://www.w3.org/1999/xlink"
		version="1.0"> 
<xsl:output method="html" version="4"/>

<xsl:template match="/">
<html>
<head>
<title>Parts Catalog</title>
<script><![CDATA[

var item_selected = null;

// When the mouse ponter triggers the mouse over event
// This function is called.
// We are using both the SVGDOM and the XML DOM
// to access the document's tree nodes.
// More particularly, this function change elements
// identified by 'part-nn" and 'desc-nn' identifiers (i.e. the id attribute).
// Note that to change a style attribute with the SVG DOM does not
// require to know in advance the value of the style attribute.
// In contrast, with the XML DOM you need to know the full content
// of the style attribute.
function on_mouse_over (ID)
{
	if (ID == item_selected)
		return true;

	var obj_name = "part-";
	obj_name = obj_name.concat(ID);
	
	// Change the SVG element's style
	// -------------------------------
	// 1 - get the SVGDOM document element from the Adobe SVG viewer
	// 2 - Then, get the element included in the SVG document and which is
	// referred by the id='part-nn' identifier.
	// nn stands for a number; Example: part-1
	// 3 - Finally, Get the style attribute from the SVG DOM element node.
	// the getStyle function is particular to the SVG DOM.
	// the get style function returns a style object.
	// We change the 'fill' style attribute with the returned
	// style object. Note that in contrast to the XML DOM
	// we do not need to know in advance the content of the
	// style attribute's value to change one of the CSS attribute.
	var svgdoc = document.figure.getSVGDocument();
	var svgobj = svgdoc.getElementById(obj_name);
	if (svgobj != null)
	{
		var svgStyle = svgobj.getStyle(); 
		svgStyle.setProperty ('fill', 'yellow'); 
	}

	// Here is what we should have if the target browser
	// would fully support the XML DOM
	// --------------------------------------------------
	// Get the element inluded in this HTML document (see in the body
	// section) and which is referred by the 'desc-nn' identifier. nn
	// stands for a number; example desc-1
	///then, Change the element's style attribute using the
	// XML DOM. Please note that in contrast to the SVG DOM
	// function, the whole style attribute's value is changed and
	// not the value of a single contained CSS attribute.
	// DOES NOT WORK...
	var svgdesc = document.getElementById(obj_name);
	if (svgdesc != null)
		svgdesc.setAttribute("style", "background-color:yellow; cursor:hand");

	// Here is what we do for the IE 5 DHTML DOM
	// -----------------------------------------
	var DHTMLobj = document.all.item(obj_name)
	if (DHTMLobj != null)
		DHTMLobj.style.backgroundColor = "yellow";
	return true;
}

// When the mouse ponter triggers the mouse over event
// This function is called.
// We are using both the SVGDOM and the XML DOM
// to access the document's tree nodes.
// More particularly, this function change elements
// identified by 'part-nn" and 'desc-nn' identifiers (i.e. the id attribute).
// Note that to change a style attribute with the SVG DOM does not
// require to know in advance the value of the style attribute.
// In contrast, with the XML DOM you need to know the full content
// of the style attribute.
function on_mouse_out (ID)
{
	if (ID == item_selected)
		return true;

	var obj_name = "part-";
	obj_name = obj_name.concat(ID);
	
	// Change the SVG element's style
	// -------------------------------
	// 1 - get the SVGDOM document element from the Adobe SVG viewer
	// 2 - Then, get the element included in the SVG document and which is
	// referred by the id='part-nn' identifier.
	// nn stands for a number; Example: part-1
	// 3 - Finally, Get the style attribute from the SVG DOM element node.
	// the getStyle function is particular to the SVG DOM.
	// the get style function returns a style object.
	// We change the 'fill' style attribute with the returned
	// style object. Note that in contrast to the XML DOM
	// we do not need to know in advance the content of the
	// style attribute's value to change one of the CSS attribute.
	var svgdoc = document.figure.getSVGDocument();
	var svgobj = svgdoc.getElementById(obj_name);
	if (svgobj != null)
	{
		var svgStyle = svgobj.getStyle(); 
		svgStyle.setProperty ('fill', 'white'); 
	}

	// Here is what we should have if the target browser
	// would fully support the XML DOM
	// --------------------------------------------------
	// Get the element inluded in this HTML document (see in the body
	// section) and which is referred by the 'desc-nn' identifier. nn
	// stands for a number; example desc-1
	///then, Change the element's style attribute using the
	// XML DOM. Please note that in contrast to the SVG DOM
	// function, the whole style attribute's value is changed and
	// not the value of a single contained CSS attribute.
	// DOES NOT WORK...
	var svgdesc = document.getElementById(obj_name);
	if (svgdesc != null)
		svgdesc.setAttribute("style", "background-color:white;");

	// Here is what we for the IE 5 DHTML DOM
	// --------------------------------------
	var DHTMLobj = document.all.item(obj_name)
	if (DHTMLobj != null)
		DHTMLobj.style.backgroundColor = "white";

	return true;
}

function on_mouse_click(ID)
{
	var obj_name = "part-";
	obj_name = obj_name.concat(ID);

	// reset the color of the previously selected part
	if (item_selected)
	{
		var svgdoc = document.figure.getSVGDocument();
		var svgobj = svgdoc.getElementById(obj_name);
		if (svgobj != null)
		{
			var svgStyle = svgobj.getStyle(); 
			svgStyle.setProperty ('fill', 'white'); 
		}
		var DHTMLobj = document.all.item(obj_name)
		if (DHTMLobj != null)
		{
			DHTMLobj.style.backgroundColor = "white";
			DHTMLobj.style.fontWeight  = "normal";
		}
	}
	// Now select the new part
	if (item_selected != ID)
	{
		var svgdoc = document.figure.getSVGDocument();
		var svgobj = svgdoc.getElementById(obj_name);
		if (svgobj != null)
		{
			var svgStyle = svgobj.getStyle(); 
			svgStyle.setProperty ('fill', '#C0C0C0'); 
		}
		var DHTMLobj = document.all.item(obj_name)
		if (DHTMLobj != null)
		{
			DHTMLobj.style.backgroundColor = "#C0C0C0";
			DHTMLobj.style.fontWeight  = "bolder";
		}
		item_selected = ID;	
	}
	else
		item_selected = null;



	return true;	
}
]]></script>
</head>

<body>
	<xsl:apply-templates/>
</body>
</html>
</xsl:template>

<xsl:template match="part[@xlink:type='extended']">
<!-- The parts catalog illustration -->
	<div align="center">
		<embed name="figure" width="540" height="540" type="image/svg" pluginspage="http://www.adobe.com/svg/viewer/install/">
		<xsl:attribute name="src"><xsl:value-of select="@xml:base"/></xsl:attribute>
		</embed>
	</div>
<!-- The parts catalog description -->
	<table border="0" cellpadding="1" cellspacing="0" width="100%" bgcolor="black">
	<tr>
		<table border="0" cellpadding="0" cellspacing="0" width="100%" bgcolor="white">
			<tr style="background-color:#990033; color:white;">
				<td align="center">Part Nbr.</td>
				<td align="center">Part Qty.</td>
				<td>Description</td>
			</tr>
			<xsl:apply-templates/>
		</table>
	</tr>
</table>
</xsl:template>

<xsl:template match="part[@xlink:type='locator']">
    <tr>
	<xsl:attribute name="id"><xsl:value-of select="substring-after(@xlink:href, '#')"/></xsl:attribute> 
	<xsl:attribute name="style">background-color:white;</xsl:attribute>
	<xsl:attribute name="onmouseover">on_mouse_over('<xsl:value-of select="substring-after(@xlink:href, '#part-')"/>')</xsl:attribute> 
	<xsl:attribute name="onmouseout">on_mouse_out('<xsl:value-of select="substring-after(@xlink:href, '#part-')"/>')</xsl:attribute>
	<xsl:attribute name="onclick">on_mouse_click('<xsl:value-of select="substring-after(@xlink:href, '#part-')"/>')</xsl:attribute>
	<td align="center"><xsl:value-of select="substring-after(@xlink:href, '#part-')"/></td>
	<td align="center"><xsl:value-of select="./qty"/></td>
	<td><xsl:value-of select="./description"/></td>
    </tr>
</xsl:template>

</xsl:stylesheet>